#Methods
##Meal preparation
We conducted a series of experiments consisting of food preparation followed by sample preparation and microbial analysis. Food was purchased and prepared in a standard American home kitchen by the same individual using typical kitchen cleaning practices including hand washing with non-antibacterial soap between food preparation steps, washing of dishes and cooking instruments with non-antibacterial dish washing detergent, and kitchen clean-up with a combination of anti-bacterial and non-antibacterial cleaning products. Anti-bacterial products had specific anti-bacterial molecules added to them whereas "non-antibacterial" products were simple surfactant-based formulations. The goal was to simulate a typical home kitchen rather than to artificially introduce sterile practices that would be atypical of how the average American prepares their meals at home. All meals were prepared according to specific recipes (from raw ingredient preparation such as washing and chopping, to cooking and mixing). 

After food preparation, meals were plated on a clean plate, weighed on a digital scale (model 157W, Escali, Minneapolis, MN), and then transferred to a blender (model 5200, Vita-Mix Corporation, Cleveland, OH) and processed until completely blended (approximately 1-3 minutes). Prepared, ready to eat foods that were purchased outside the home were simply weighed in their original packaging and then transferred to the blender. 4 mL aliquots of the blended meal composite were extracted from the blender, transported on dry ice and then stored at -80°C until analysis. The following analyses were completed using these meal composite samples: 1) total aerobic bacterial plate counts, 2) total anaerobic bacterial plate counts, 3) yeast plate counts, 4) fungal plate counts, and 5) 16S rDNA analysis for microbial ecology. 

##Diet design
Diets were designed by a nutritional biologist to deliver the average number of Calories consumed by an average American per day. The average American woman is 63 inches in height and weighs 166 pounds, and the average American man is 69 inches in height and weighs 195 pounds with an average age of 35, [National Health and Nutrition Examination Survey](http://www.cdc.gov/nchs/data/nhanes/databriefs/adultweight.pdf), which translates to a total daily Calorie intake range of 2,000 to 2,600 Calories per day respectively to maintain weight, as determined using the [USDA MyPlate SuperTracker tool](https://www.supertracker.usda.gov/MyWeightManager.aspx. 2010). Therefore an intermediate daily Calorie intake of about 2,200 Calories was chosen as the target.  

Meal plans were created using the NutriHand program (Nutrihand Inc., Soraya, CA). Diet nutrient composition was calculated by the NutriHand program from reference nutrient data for individual foods using the [USDA National Nutrient Database for Standard Reference](http://ndb.nal.usda.gov). Three one-day meal plans were created to be representative of three typical dietary patterns that are consumed by Americans: 1) the Average American dietary pattern (AMERICAN), which includes meat and dairy and focuses on convenience foods, 2) the USDA recommended dietary pattern (USDA), which emphasizes fresh fruits and vegetables, lean meats, whole grains and whole grain products, and dairy, and 3) the Vegan dietary pattern (VEGAN), which excludes all animal products. The AMERICAN meal plan totaled 2268 Calories, which consisted of 35% fat, 53% carbohydrates of which 16.6 g was fiber, and 12% protein. The USDA meal plan totaled 2260 Calories, consisting of 25% fat, 49% carbohydrates of which 45 g was fiber, and 27% protein. The VEGAN meal plan totaled 2264 Calories and consisted of 31% fat, 54% carbohydrates of which 52 g was fiber, and 15% protein. 

##Microbial community analysis
Microbial plate counts were performed by Covance Laboratories (Covance Inc., Madison, WI). Aerobic plate counts were performed according to [SPCM:7](http://www.fda.gov/Food/FoodScienceResearch/LaboratoryMethods/ucm063346.htm), anaerobic plate counts were performed according to [APCM:5](http://www.fda.gov/food/foodscienceresearch/laboratorymethods/ucm073598.htm) and the yeast and mold counts were performed according to Chapter 23 of the FDA's [Bacteriological Analytical Manual](http://www.fda.gov/food/foodscienceresearch/laboratorymethods/ucm073598.htm). Plate counts were reported as colony forming units (CFU) per gram for each meal composite. The CFU/g values were multiplied by the total number of grams in each meal to obtain the CFU per meal, and the values for meals for each day were added to obtain the CFU per day for each dietary pattern (Table 1). 

The taxonomic composition of each meal microbiome was assessed via amplification and sequencing of 16S rDNA from the homogenized meals.  DNA was extracted from homogenized food samples with the Power Food Microbial DNA Isolation Kit (MoBio Laboratories, Inc.) according to the manufacturer’s protocol. Microbial DNA was amplified by a two-step PCR enrichment of the 16S rRNA gene (V4 region) using primers 515F and 806R, modified by addition of Illumina adaptor and barcodes sequences. All primer sequences and a detailed PCR protocol are provided in Table 2 and in a GitHub repository (https://github.com/hollybik/protocols/blob/master/16S_rRNA_twostep_PCR.tex), respectively. Libraries were sequenced using an Illumina MiSeq system, generating 250bp paired-end amplicon reads.  The amplicon data was multiplexed using dual barcode combinations for each sample.  We used a custom script (available in a GitHub repository (https://github.com/gjospin/scripts/blob/master/Demul_trim_prep.pl), to assign each pair of reads to their respective samples when parsing the raw data.  This script allows for 1 base pair difference per barcode.  The paired reads were then aligned and a consensus was computed using FLASH \cite{21903629} with maximum overlap of 120 and a minimum overlap of 70 (other parameters were left as default). The custom script automatically demultiplexes the data into fastq files, executes FLASH, and parses its results to reformat the sequences with appropriate naming conventions for QIIME v. 1.8.0 \cite{20383131} in fasta format. The resulting consensus sequences were analyzed using the QIIME pipeline.

##Statistical Analyses and Data Visualization
Unless otherwise noted, all statistical analyses were performed using python scripts implemented in QIIME v. 1.8.0, and all python scripts referenced here are QIIME scripts. The IPython notebook file used for all QIIME analyses is available at http://nbviewer.ipython.org/gist/jennomics/c6fe5e113525c6aa8add. To explore the differences in overall microbial community composition across the 15 meals, both the phylogenetic weighted UniFrac distances \cite{20827291} and the taxonomic Bray-Curtis dissimilarities \cite{Bray_1957} were calculated using the beta\_diversity\_through\_plots.py script. This script also produced a principal coordinates analysis (PCoA) plot in which the Bray-Curtis dissimilarities between samples were used to visualize differences among groups of samples (see Figure 1 for this type of visualization for the three Diet Types.) To test for the significance of dietary pattern on the overall microbial community composition, we used a permutational multivariate ANOVA as implemented in the compare\_categories.py script. To test for significant differences in taxonomic richness across dietary patterns, we used the non-parametric Kruskal-Wallis test \cite{Kruskal_1952} with the FDR (false discovery rate) correction as implemented in compare\_alpha\_diversity.py. To test for the significant variation in frequency of individual OTUs across dietary patterns, we used the Kruskal-Wallis test with the FDR correction as implemented in the group\_significance.py script. We also used the biplot function of the make\_emperor.py script to plot the family-level OTUs in PCoA space alongside each meal. To test for significant correlation between the relative abundance of a single taxonomic group and meal metadata categories (i.e. nutrient composition, whether a meal contains fermented foods, etc) at 5 taxonomic levels (phylum-genus) Pearson correlation coefficients \cite{Pearson_1895} were calculated and tested for statistical significance using Stata (StataCorp. 2013. Stata Statistical Software: Release 13. College Station, TX: StataCorp LP.) Figures 2 and 3 were produced with R \cite{R}, using the phyloseq package \cite{23630581}.

##Metagenome Prediction with PICRUSt
A synthetic metagenome was generated based on the observed 16S rDNA sequences for each meal. To do this, the 16S rDNA sequences were clustered into a collection of OTUs sharing 99% sequence identity, using the pick\_closed\_reference\_otus.py script. The resultant OTU table was normalized with respect to inferred 16S rRNA gene copy numbers using the normalize\_by\_copy\_number.py script distributed with PICRUSt v. 1.0.0 \cite{23975157}. The normalized OTU table was used to predict meal microbial metagenomes with PICRUSt's predict\_metagenomes.py script. The final predicted metagenome is output as a .biom table, which is suitable for analysis with a tool such as STAMP \cite{25061070}. We used STAMP to test for and visualize significant (predicted) functional differences in microbial communities between the three dietary patterns.
