#Summary

In this study we estimated the total numbers and kinds of microorganisms consumed in a day by an average American adult. We analyzed meals representing three typical dietary patterns, including the Average American, USDA recommended, and Vegan diet, and found that Americans likely consume in the range of \(10^6\) – \(10^9\) CFU microbes per day. The USDA meal plan included two meals with non-heat treated fermented foods, which were likely responsible for the 3-fold higher total microbes in this meal plan compared to the AMERICAN and VEGAN diets. Food preparation techniques such as heating or acid treatment can kill bacteria, however, these processes affect different bacteria to different degrees. For example, spore-forming bacteria can survive heat treatment \cite{Stringer_2011} (also see Figure 8). Once inside the gastrointestinal tract, the low pH of the stomach, as well as bile salts also kill some bacteria, but not those that are acid and/or bile salt resistant. It is unknown what proportion of the microbes we eat make it through the hostile environment of the gastrointestinal tract. However, a recent study showed that food microbes consumed as part of fermented foods such as cheese did appear in the stool and were culturable \cite{David_2013}. 

We also used PICRUSt to predict the functional potential of the microbiota associated with each meal in this study. Of course, this is not a perfect substitute for metagenomic sequencing or experimental studies, but it does allow one to develop some initial hypotheses related to the function of a microbial community. For example, between diet types, the most significant difference in KEGG functional categories was for “other N-glycan degradation.” This function was over-represented in the Vegan diet, which is perhaps not surprising given that cellulose is a glycan, and the Vegan diet is significantly higher in cellulose than the others. This suggests that when one consumes a diet that is high in cellulose, one also consumes a population of microbes that is well equipped to digest cellulose. 

##Caveats
It is important to point out some caveats with regard to this study. First, the scale of this study was limited. Our objective with this preliminary study was to explore the possiblity that the microbes in our food may be meaningful contributors to the ecosystem of our gut microbiota. The current paradigm is that the harsh conditions of the human gastrointestinal tract (_i.e._ high acidity in the stomach, presence of bile acids and digestive enzymes in the small intestine) preclude most microbes present in and on food from playing significant roles in the gastrointestinal microbial ecosystem because they do not survive intact. Yet recent reports show that there are microbial blooms within 24 hours of large shifts in the diet \cite{Wu_2011}\cite{Walker_2010}, attributed to changes in the available fermentable substrate, which in turn promoted the growth of specific bacteria already present in the gut. The possiblity remains that microbes present on the food itself contributed at least in part to these observed transient blooms or shifts. Very little is known about how different food matrices may promote the survival of food bacteria despite their lack of acid and bile acid resistance in vitro. Transient shifts in gut microbiome composition caused by dietary factors may be unimportant when the gut microbiome rebounds to its initial state. However, it is possible that under certain conditions, such perturbations could lead to functional and long-lasting changes. The goal of this study was not to explore the explicit effects of ingesting food microbes on changes in the gut microbiota but simply to provide preliminary data on the composition and numbers of bacteria in typical American dietary patterns. 

Second, the study did not aim to be exhaustive in its exploration of diets. We did not aim to produce statistically significant differences in microbial composition and quantity in replicates across multiple days of a particular dietary pattern. Instead, the aim was to generate hypotheses about dietary microbes and their variation across meals and diets that can now be followed up with more rigorous studies. Because the purpose of this study was to generate hypotheses rather than test specific hypotheses, multiple testing corrections were not applied in our statistical analyses. 

Third, the microbial counts reported here are rough estimates of the total amount of microbes consumed in a day by an average American eating meals described here. It is important to note that inherent to the plate count techniques used, not every microbe will grow under these culture conditions, and the plate counts are only estimates.

##Future Directions 
It is possible that part of the high variation in gut microbiota composition observed among individuals is due to the specific and complex differences in diet beyond the nutrient composition that can be estimated from dietary records and recalls. This study begs the question: do the microbes we eat as part of our normal daily diets contribute to the composition and function of our gut microbiota? There are many questions that remain to be answered. Under what circumstances do microbes consumed as part of meals remain in the gastrointestinal tract transiently versus persistently following a meal? Do the microbes we eat affect the function of the resident gut microbiota, even if they do not affect its composition, as has been suggested by some yogurt feeding studies \cite{McNulty_2011}? How do different cooking and preparation methods affect the microbial composition of meals and the survival characteristics of individual microbes through the gastrointestinal tract? How do specific factors such as length of transport or provenance of individual ingredients (_e.g._ imported vs. domestic), packaging materials, and handling of ingredients in homes alter the microbial composition of foods? The findings of this study suggest that the microbes we eat as part of normal diets vary in absolute abundance, community composition, and functional potential. This variation depends on the specific ingredients in the meals, whether and how the foods are prepared and processed, and other potential factors, not explored here, including the provenance of ingredients. The significance of this variation on the gut microbiota composition and function, and its impact on human health remains to be elucidated. In addition, much as certain gut microbes can transform and modify dietary constituents and nutrients such as polyphenolic compounds and vitamins in the gut \cite{Tuohy_2012}, it is possible that food microbes similarly modify nutritive molecules. Future studies need to explore these questions in rigorous study designs aimed at addressing key questions about the composition and content of food microbes and how these vary across diets and meals, and their impacts on the short term and long term composition and function of the gut microbiota.

All data underlying the results presented here can be found on Figshare (http://figshare.com/account/projects/2225). 
